==> mod_layout-3.2.1.tar.gz: mod_layout-3.2.1/directives.h <==
/* 
**  mod_layout_directives.h -- Commands for mod_layout
**  $Revision: 1.5 $
*/

#define LayoutCacheNeeded "This directives makes sure that all Layout headers and footers get Cache-Control: no-cache methods in all situations. This directive either takes On or Off."
#define LayoutHeader "A URI which prints the header contents."
#define LayoutFooter "A URI which prints the footer contents."
#define Layout "Add a layout to be inserted when a tag is found, this takes two options, with a third optional parameter. The first is a pattern, the second is the layout and the third is how the layout should be inserts (either prepend, append, or replace). The default is to replace. "
#define LayoutHandler "Enter either a mime type or a handler type. This type will then be handled by mod_layout."
#define LayoutIgnoreURI "Enter a URI that should be ignored, regular expressions are allowed."
#define LayoutIgnoreHeaderURI "Enter a URI that should be ignored by the header, regular expressions are allowed."
#define LayoutIgnoreHTTPHeaderURI "Enter a URI that should be ignored by the HTTPHeader, regular expressions are allowed."
#define LayoutIgnoreFooterURI "Enter a URI that should be ignored by the footer, regular expressions are allowed."
#define LayoutComment "This can either be On or Off (default it Off). It places HTML comments in the outbound text describing when and where mod_layout has been inserting text."
#define LayoutProxy "This can either be On or Off (default it Off). This is both experimental and probably quite broke."
#define LayoutDisplayOriginal "This can either be On or Off (default it On). When off the original document is not displayed."
#define LayoutDefaultHandlers "Turns On (default) or Off a list of standard types to handle."
#define LayoutTimeFormat "This takes a SSI style timme format that can be used to change the output by mod_layout's internal TIME environmental variables that it introduces."
#define LayoutHTTPHeader "Takes a URI to call for the HTTP Header."
#define LayoutHTTPOverrideHandler "Specify handlers that mod_layout should produce HTTP headers for."
#define LayoutHTTPOverrideURI "Specify URI's that mod_layout should produce HTTP headers for."
#define LayoutFooterOff "This takes no arguments. If found it will turn off the footer."
#define LayoutHeaderOff "This takes no arguments. If found it will turn off the header."
#define LayoutHTTPHeaderOff "This takes no arguments. If found it will turn off the http header."
#define LayoutPostAsync "Turns on and off asynchronous POSTs (AKA everything can see the post data)."
#define LayoutCache "This moves the default cache from /tmp to another directory(or a RAM disk)."
#define LayoutAppend "Turning this On or Off afffects whether or not headers and footers are appended when creating subsections."
#define LayoutMerge "Turning this on and off will tell mod_layout to attempt to resolve conten (do a merger of the footer, body and header text"
#define LayoutMergeBeginTag "Use this to change the default begin tag to use during merges (the default string is \"<HTML>\""
#define LayoutMergeEndTag "Use this to change the default end tag to use during merges (the default string is \"<\\HTML>\""
#define LayoutHeaderAppend "Use this to change the default end tag to use during merges (the default string is \"<\\HTML>\""
#define LayoutFooterAppend "Use this to change the default end tag to use during merges (the default string is \"<\\HTML>\""
#define LayoutMergeErrorIgnore "When enabled (it takes on and off flags) mod_layout will not try to wrap any errors. Merge must be enabled for this to work. The default for this is off."
#define LayoutIgnoreTag "If this tag is found during a merge, no footer or header will be inserted into the document"
#define LayoutIgnoreTagFooter "If this tag is found during a merge, no footer will be inserted into the document"
#define LayoutIgnoreTagHeader "If this tag is found during a merge, no header will be inserted into the document"
#define LayoutHTMLHandler "This turns on mod_layout's own text/html and text/plain handler"
#define LayoutReplaceTags "If this is enabled and you are doing a merge, the tags used for the merge will be replaced."
#define LayoutNotes "If you want applications to do notes (a set of directives to control actions inside apache)."

==> mod_layout-3.4.tar.gz: mod_layout-3.4/directives.h <==
/* 
**  mod_layout_directives.h -- Commands for mod_layout
**  $Revision: 1.5 $
*/

#define LayoutCacheNeeded "This directives makes sure that all Layout headers and footers get Cache-Control: no-cache methods in all situations. This directive either takes On or Off."
#define LayoutHeader "A URI which prints the header contents."
#define LayoutFooter "A URI which prints the footer contents."
#define Layout "Add a layout to be inserted when a tag is found, this takes two options, with a third optional parameter. The first is a pattern, the second is the layout and the third is how the layout should be inserts (either prepend, append, or replace). The default is to replace. "
#define LayoutHandler "Enter either a mime type or a handler type. This type will then be handled by mod_layout."
#define LayoutIgnoreURI "Enter a URI that should be ignored, regular expressions are allowed."
#define LayoutIgnoreHeaderURI "Enter a URI that should be ignored by the header, regular expressions are allowed."
#define LayoutIgnoreHTTPHeaderURI "Enter a URI that should be ignored by the HTTPHeader, regular expressions are allowed."
#define LayoutIgnoreFooterURI "Enter a URI that should be ignored by the footer, regular expressions are allowed."
#define LayoutComment "This can either be On or Off (default it Off). It places HTML comments in the outbound text describing when and where mod_layout has been inserting text."
#define LayoutProxy "This can either be On or Off (default it Off). This is both experimental and probably quite broke."
#define LayoutDisplayOriginal "This can either be On or Off (default it On). When off the original document is not displayed."
#define LayoutDefaultHandlers "Turns On (default) or Off a list of standard types to handle."
#define LayoutTimeFormat "This takes a SSI style timme format that can be used to change the output by mod_layout's internal TIME environmental variables that it introduces."
#define LayoutHTTPHeader "Takes a URI to call for the HTTP Header."
#define LayoutHTTPOverrideHandler "Specify handlers that mod_layout should produce HTTP headers for."
#define LayoutHTTPOverrideURI "Specify URI's that mod_layout should produce HTTP headers for."
#define LayoutFooterOff "This takes no arguments. If found it will turn off the footer."
#define LayoutHeaderOff "This takes no arguments. If found it will turn off the header."
#define LayoutHTTPHeaderOff "This takes no arguments. If found it will turn off the http header."
#define LayoutPostAsync "Turns on and off asynchronous POSTs (AKA everything can see the post data)."
#define LayoutCache "This moves the default cache from /tmp to another directory(or a RAM disk)."
#define LayoutAppend "Turning this On or Off afffects whether or not headers and footers are appended when creating subsections."
#define LayoutMerge "Turning this on and off will tell mod_layout to attempt to resolve content (do a merger of the footer, body and header text"
#define LayoutMergeBeginTag "Use this to change the default begin tag to use during merges (the default string is \"<HTML>\""
#define LayoutMergeEndTag "Use this to change the default end tag to use during merges (the default string is \"<\\HTML>\""
#define LayoutHeaderAppend "Use this to change the default end tag to use during merges (the default string is \"<\\HTML>\""
#define LayoutFooterAppend "Use this to change the default end tag to use during merges (the default string is \"<\\HTML>\""
#define LayoutMergeErrorIgnore "When enabled (it takes on and off flags) mod_layout will not try to wrap any errors. Merge must be enabled for this to work. The default for this is off."
#define LayoutIgnoreTag "If this tag is found during a merge, no footer or header will be inserted into the document"
#define LayoutIgnoreTagFooter "If this tag is found during a merge, no footer will be inserted into the document"
#define LayoutIgnoreTagHeader "If this tag is found during a merge, no header will be inserted into the document"
#define LayoutHTMLHandler "This turns on mod_layout's own text/html and text/plain handler"
#define LayoutReplaceTags "If this is enabled and you are doing a merge, the tags used for the merge will be replaced."
#define LayoutNotes "If you want applications to do notes (a set of directives to control actions inside apache)."
